[][src]Trait svc_error::ProblemDetailsReadOnly

pub trait ProblemDetailsReadOnly {
    fn kind(&self) -> &str;
fn title(&self) -> &str;
fn status_code(&self) -> StatusCode;
fn detail(&self) -> Option<&str>; }

Getters for Problem Details

Required methods

fn kind(&self) -> &str

Return a URI reference RFC3986 that identifies the problem type. This specification encourages that, when dereferenced, it provide human-readable documentation for the problem type. When this member is not present, its value is assumed to be "about:blank".

fn title(&self) -> &str

Return a short, human-readable summary of the problem type. It SHOULD NOT change from occurrence to occurrence of the problem, except for purposes of localization

fn status_code(&self) -> StatusCode

Return the HTTP status code generated by the origin server for this occurrence of the problem.

fn detail(&self) -> Option<&str>

Return a human-readable explanation specific to this occurrence of the problem.

Loading content...

Implementors

impl ProblemDetailsReadOnly for Error[src]

Loading content...